@@ -10,7 +10,7 @@ from dataclasses import dataclass
 from typing import Optional, Dict
 from metricflow.cli.main import _print_issues
 from metricflow.model.parsing.config_linter import ConfigLinter
-from metricflow.model.parsing.dir_to_model import collect_yaml_config_file_paths
+from metricflow.model.parsing.dir_to_model import ModelBuildResult, collect_yaml_config_file_paths
 from metricflow.model.validations.validator_helpers import ModelValidationResults
 
 EXPECTED_TF_CONFIG_FILE_NAMES = [
@@ -19,6 +19,7 @@ EXPECTED_TF_CONFIG_FILE_NAMES = [
     "validate_configs.yaml",
     "commit_configs.yaml",
     "bitbucket-pipelines.yml",
+    ".gitlab-ci.yml",  # this should be ignored by collect_yaml_config_file_paths() but it's not
 ]
 TRANSFORM_API_URL = "https://api.transformdata.io"
 UPLOAD_MODE_VALIDATE = "validate"
@@ -162,28 +163,15 @@ def hash_config_files(yaml_files: Dict[str, str]) -> Dict[str, str]:  # noqa: D
     return hash_to_filename
 
 
-def commit_configs(
+def upload_transform_configs(
+    api_url: str,
     auth_header: Dict[str, str],
     repo: str,
     branch: str,
     commit: str,
-    config_dir: str = LOCAL_DIR_DEFAULT,  # default to local dir
-    is_validation: bool = False,
-    api_url: str = TRANSFORM_API_URL,  # default to prod api
-    return_issues: bool = False,
-) -> requests.Response:
-    """Creates either a validated or validation model based on `is_validation`
-
-    Parses configs, runs semantic validations, and creates a validation or validated
-    model based on `is_validation`
-    """
-    # Sometimes people accidentally override their local TRANSFORM_API_URL
-    # environment variable with an empty string instead of UNSET-ing it.
-    # And then an empty string propagates all the way here. So if api_url
-    # is empty, default it. It's worth noting that in python "" evaluates to
-    # false, which is why this oneliner works.
-    api_url = api_url or TRANSFORM_API_URL
-
+    config_dir: str,
+):
+    """Uploads a directory of transform model configs to the backend at the specified `api_url`"""
     # get the config files
     yaml_files = read_config_files(config_dir)
     hash_to_filename = hash_config_files(yaml_files)
@@ -233,6 +221,88 @@ def commit_configs(
     if r.status_code != 200:
         raise Exception(f"Failed uploading config yaml files. {r.text}")
 
+
+def upload_model_from_dbt_project(
+    api_url: str,
+    auth_header: Dict[str, str],
+    repo: str,
+    branch: str,
+    commit: str,
+    config_dir: str,
+    profile: Optional[str] = None,
+    target: Optional[str] = None,
+):
+    """Parses a dbt project into a UserConfiguredModel, serializes it, and then uploads it"""
+    # This import results in eventually importing dbt, and dbt is an optional
+    # dep meaning it isn't guaranteed to be installed. If the import is at the
+    # top ofthe file transform-tools will blow up if dbt isn't installed. Thus
+    # by importing it here, we only run into the exception if this method is
+    # hit without dbt installed
+    from metricflow.model.parsing.dbt_dir_to_model import parse_dbt_project_to_model
+
+    headers = {**{"Content-Type": "application/json"}, **auth_header}
+    verify = api_url.startswith("https")
+
+    # Build the model from the dbt project
+    results: ModelBuildResult = parse_dbt_project_to_model(directory=config_dir, profile=profile, target=target)
+
+    # Add the serialized model to backend file storage
+    add_serialized_model_url = f"{api_url}/api/v1/model/{repo}/{branch}/{commit}/add_serialized_model"
+    logger.info(f"add_serialized_model_url: {add_serialized_model_url}")
+    logger.info("Uploading serialized model")
+    r = requests.post(
+        add_serialized_model_url,
+        json={"serialized_model": results.model.json()},
+        headers=headers,
+        verify=verify,
+    )
+    if r.status_code != 200:
+        raise Exception(f"Failed uploading serialized model. {r.text}")
+
+
+def commit_configs(
+    auth_header: Dict[str, str],
+    repo: str,
+    branch: str,
+    commit: str,
+    config_dir: str = LOCAL_DIR_DEFAULT,  # default to local dir
+    is_validation: bool = False,
+    api_url: str = TRANSFORM_API_URL,  # default to prod api
+    return_issues: bool = False,
+    is_dbt_model: bool = False,
+    dbt_profile: Optional[str] = None,
+    dbt_target: Optional[str] = None,
+) -> requests.Response:
+    """Creates either a validated or validation model based on `is_validation`
+
+    Parses configs, runs semantic validations, and creates a validation or validated
+    model based on `is_validation`
+    """
+    # Sometimes people accidentally override their local TRANSFORM_API_URL
+    # environment variable with an empty string instead of UNSET-ing it.
+    # And then an empty string propagates all the way here. So if api_url
+    # is empty, default it. It's worth noting that in python "" evaluates to
+    # false, which is why this oneliner works.
+    api_url = api_url or TRANSFORM_API_URL
+    headers = {**{"Content-Type": "application/json"}, **auth_header}
+    verify = api_url.startswith("https")
+
+    if is_dbt_model:
+        upload_model_from_dbt_project(
+            api_url=api_url,
+            auth_header=auth_header,
+            repo=repo,
+            branch=branch,
+            commit=commit,
+            config_dir=config_dir,
+            profile=dbt_profile,
+            target=dbt_target,
+        )
+    else:
+        upload_transform_configs(
+            api_url=api_url, auth_header=auth_header, repo=repo, branch=branch, commit=commit, config_dir=config_dir
+        )
+
     # This route validates the configs for files we just pushed and, if there are no
     # errors it then creates a semantic model from those configs in the backend database
     commit_url = f"{api_url}/api/v1/model/{repo}/{branch}/{commit}/commit_model"
@@ -242,7 +312,14 @@ def commit_configs(
         commit_url,
         headers=headers,
         verify=verify,
-        json=json.dumps({"is_current": False, "is_validation": is_validation, "return_issues": return_issues}),
+        json=json.dumps(
+            {
+                "is_current": False,
+                "is_validation": is_validation,
+                "return_issues": return_issues,
+                "is_dbt_model": is_dbt_model,
+            }
+        ),
     )
     if r.status_code != 200:
         err_msg = _err_msg_from_err_response(r)
@@ -260,6 +337,9 @@ def commit_configs_as_primary(
     config_dir: str = LOCAL_DIR_DEFAULT,  # default to local dir
     api_url: str = TRANSFORM_API_URL,  # default to prod api
     return_issues: bool = False,
+    is_dbt_model: bool = False,
+    dbt_profile: Optional[str] = None,
+    dbt_target: Optional[str] = None,
 ) -> requests.Response:
     """Creates a model from the configs and makes it the primary model
 
@@ -281,6 +361,9 @@ def commit_configs_as_primary(
         is_validation=False,
         api_url=api_url,
         return_issues=return_issues,
+        is_dbt_model=is_dbt_model,
+        dbt_profile=dbt_profile,
+        dbt_target=dbt_target,
     )
 
     json_resp = response.json()
@@ -311,6 +394,9 @@ def validate_configs(
     config_dir: str = LOCAL_DIR_DEFAULT,  # default to local dir
     api_url: str = TRANSFORM_API_URL,  # default to prod api
     return_issues: bool = False,
+    is_dbt_model: bool = False,
+    dbt_profile: Optional[str] = None,
+    dbt_target: Optional[str] = None,
 ) -> requests.Response:
     """Parses configs, runs semantic validations, and creates a validation model"""
     return commit_configs(
@@ -322,6 +408,9 @@ def validate_configs(
         is_validation=True,
         api_url=api_url,
         return_issues=return_issues,
+        is_dbt_model=is_dbt_model,
+        dbt_profile=dbt_profile,
+        dbt_target=dbt_target,
     )
 
 
@@ -366,6 +455,9 @@ if __name__ == "__main__":
         model_details = parse_github()
 
     API_URL = os.getenv("TRANSFORM_API_URL", TRANSFORM_API_URL)
+    IS_DBT_MODEL = os.getenv("IS_DBT_PROJECT", "").lower() in ["yes", "y", "true", "t", "1"]
+    DBT_PROFILE = os.getenv("TFD_DBT_PROFILE")
+    DBT_TARGET = os.getenv("TFD_DBT_TARGET")
 
     TRANSFORM_CONFIG_DIR = os.getenv("TRANSFORM_CONFIG_DIR")
     if TRANSFORM_CONFIG_DIR:
@@ -401,6 +493,9 @@ if __name__ == "__main__":
                 commit=COMMIT,
                 config_dir=TRANSFORM_CONFIG_DIR or LOCAL_DIR_DEFAULT,
                 api_url=API_URL,
+                is_dbt_model=IS_DBT_MODEL,
+                dbt_profile=DBT_PROFILE,
+                dbt_target=DBT_TARGET,
             )
         else:  # mode == UPLOAD_MODE_COMMIT
             commit_configs_as_primary(
@@ -410,6 +505,9 @@ if __name__ == "__main__":
                 commit=COMMIT,
                 config_dir=TRANSFORM_CONFIG_DIR or LOCAL_DIR_DEFAULT,
                 api_url=API_URL,
+                is_dbt_model=IS_DBT_MODEL,
+                dbt_profile=DBT_PROFILE,
+                dbt_target=DBT_TARGET,
             )
     except Exception as e:
         print(e)
